/*
	  Removes blank lines from a tex file.
 
		Compilation: g++ -o parser1 parser1.cc
		Syntax:  ./parser1 filename

		Author: Warwick Tucker <warwick@math.uu.se>
		Latest edit: Wed Nov 27 15:18:26 CET 2013
    
*/
#include <sstream>
#include <iostream>
#include <fstream>
#include <stdio.h>

using namespace std;

void removeBlankLines(string fileName)
{ 
  ifstream inFile(fileName.c_str(), ios_base::in);
  if ( !inFile ) 
    cout << "Cannot open file: '" << fileName << "' for reading" << endl;
  else {
		string outFileName = fileName + ".no_blanks";
		ofstream outFile;
		outFile.open(outFileName.c_str(), ios_base::out);
    cout << "Opened " << fileName << " for reading.";
    while ( !inFile.eof() ) {
		  string line;
      getline(inFile, line);
      if ( !line.empty() ) {
				string lineNoWS = line;
				lineNoWS.erase(lineNoWS .find_last_not_of(" \n\r\t")+1);
				if ( !lineNoWS.empty() ) 
				  outFile << lineNoWS << endl;
			}
    }
    outFile.close();
    cout << " Done writing to " << outFileName << "." << endl;
  }
}

void removeTheRest(string inFileName)
{
	string fileName = inFileName + ".no_blanks";
  ifstream inFile(fileName.c_str(), ios_base::in);
  if ( !inFile ) 
    cout << "Cannot open file: '" << fileName << "' for reading" << endl;
  else {
		string outFileName = inFileName + ".no_scrap";
		ofstream outFile;
		outFile.open(outFileName.c_str(), ios_base::out);
    cout << "Opened " << fileName << " for writing.";
    while ( !inFile.eof() ) {
		  string line;
      getline(inFile, line);
      if ( line.find("time = 0.0")!=string::npos ) {
				getline(inFile, line); 
			}
      if ( line.find("time")!=string::npos ) {
				getline(inFile, line); 
				getline(inFile, line);
			}
			if ( line.find("T =")!=string::npos ) {
				getline(inFile, line); 
				getline(inFile, line); 
			}
      if ( (line.find("%")==string::npos) && (line.find("_")==string::npos) )
        outFile << line << endl;
    }
    outFile.close();
    cout << " Done writing to " << outFileName << "." << endl;
  }	
}

string int2string(int number)
{
   stringstream ss;//create a stringstream
   ss << number;   //add number to the stream
   return ss.str();//return a string with the contents of the stream
}

void splitIntoOrbits(string inFileName)
{
	string fileName = inFileName + ".no_scrap";
  ifstream inFile(fileName.c_str(), ios_base::in);
  if ( !inFile ) 
    cout << "Cannot open file: '" << fileName << "' for reading" << endl;
  else {
		while ( !inFile.eof() ) {
			int N1, N2, N3;
			string line, symbolSequence;
			inFile >> N1 >> N2 >> N3 >> symbolSequence;
			cout << N1 << "; " << N2 << "; " << N3 << "; " << symbolSequence << endl;
			if ( symbolSequence.length() != N3 )
				break;
			getline(inFile, line);
			string outFileName = "lor_" + int2string(N3) + "_" + symbolSequence + ".txt";
			fstream myfile(outFileName.c_str(), ios_base::in);
			if (myfile)	{
				cout << outFileName << " already exists!" << endl;
			}
			ofstream outFile;
			outFile.open(outFileName.c_str(), ios_base::out);
			cout << "Opened " << outFileName << " for writing.";
			for (int i = 1; i <= N3; ++i) {
				getline(inFile, line);
				outFile << line << endl;
				getline(inFile, line);
				outFile << line << endl;
				getline(inFile, line);
			}
			getline(inFile, line);
			getline(inFile, line);
			getline(inFile, line);
			outFile.close();
      cout << " Done writing to " << outFileName << "." << endl;
		}
	}
}

int main(int argc, char* argv[])
{
	if (argc != 2) 
		cout << "Syntax: " << argv[0] << " filename" << endl;
	else {
		string fileName = argv[1];	
		removeBlankLines(fileName);
		removeTheRest(fileName);
		splitIntoOrbits(fileName);
	}
	return 0;
}
